@@ -371,7 +371,7 @@ pub fn tests_line_segment() {
 
 #[test]
 pub fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     test_part_one!("R8,U5,L5,D3\nU7,R6,D4,L4" => 6);
     test_part_one!("R8,U5,L5,D3\nU7,R6,D4,L4" => 6);
