@@ -92,7 +92,7 @@ pub fn solve(input: &mut Input) -> Result<u64, String> {
 
 #[test]
 pub fn tests() {
-    use crate::test_part_one;
+    use crate::input::test_part_one;
 
     let example = "5764801\n17807724";
     test_part_one!(example => 14_897_079);
